/**
 * Table多选数据返回类型
 * @type {{RAW_DATA_ID: string, RAW_DATA: string}}
 */
export const MULTIPLE_DATA_TYPE = Object.freeze({
  RAW_DATA: "RAW_DATA",
  RAW_DATA_ID: "RAW_DATA_ID"
});
/**
 * Table操作，增加，删除，选择obj数据,选择数据ids
 * @type {{ADD: string, DELETE: string, DATA_OBJS: string, DATA_IDS: string}}
 */
export const TABLE_OPERATION_TYPE = Object.freeze({
  ADD: "ADD",
  DELETE: "DELETE",
  DATA_OBJS: "DATA_OBJS",
  DATA_IDS: "DATA_IDS"
});
/**
 * Table行操作，增加，删除，选择obj数据,选择数据ids
 * @type {{DELETE: string, DATA_OBJ: string, DATA_ID: string, DETAIL: string}}
 */
export const TABLE_COLUMN_OPERATION_TYPE = Object.freeze({
  DELETE: "DELETE",
  DETAIL: "DETAIL",
  DATA_OBJ: "DATA_OBJ",
  DATA_ID: "DATA_ID",
});
/**
 * Tab页的操作属性
 * @type {{component: string, label: string, key: string}}
 */
export const TABS_KEY = {
  id: "tabId",
  label: "menuName",
  component: "menuTab",
  menu: "menu",
  params: "params"
};
/**
 * 权限键
 * @type {{code: string, id: string}}
 */
export const PERMISSION_KEY = {
  id: "baseId",
  code: "perCode"
};
/**
 * 菜单键
 * @type {{tab: string, children: string, icon: string, id: string, label: string, parentId: string}}
 */
export const MENU_KEY = {
  id: "baseId",
  parentId: "parentBaseId",
  label: "menuName",
  icon: "menuIcon",
  children: "children",
  permissions: "permissions",
  tab: "menuTab",
  params: "params"
};
/**
 * 本地数据KEY
 * @type {{LOGIN_DATA: string, VUEX_STORE_BIZ: string}}
 */
export const LOCAL_STORAGE_KEY = Object.freeze({
  VUEX_STORE_INIT: "VUEX_STORE_INIT",
  VUEX_STORE_BIZ: "VUEX_STORE",
  LOGIN_DATA: "LOGIN_DATA"
});

/**
 * 主题颜色
 * @type {Readonly<{theme_default: string, theme_black: string, theme_light: string}>}
 */
export const THEME_NAMES_KEY = Object.freeze({
  theme_default: "theme-default",
  theme_black: "theme-black",
  theme_light: "theme-light"
});
/**
 * 主题颜色
 * @type {({name: string, desc: string}|{name: string, desc: string}|{name: string, desc: string})[]}
 */
export const THEME_NAMES = Object.freeze([
  {name: THEME_NAMES_KEY.theme_default, url: require('@nf/assets/logo.png'), desc: "默认"},
  {name: THEME_NAMES_KEY.theme_light, url: require('@nf/assets/logo.png'), desc: "炫光白"},
]);
/**
 * 显示层级
 * @type {{z_context_index: number}}
 */
export const Z_INDEX = {
  z_context_index: 999,
};
/**
 * 分页组件key
 * @type {{total: string, curPage: string, pageSize: string, pageData: string}}
 */
export const PAGE_KEY = {
  curPage: "curPage",
  total: "total",
  pageSize: "pageSize",
  pageData: "pageData"
};
/**
 *
 * @type {{code: {access_token_exp_code: string, access_denied_code: string, refresh_token_exp_code: string}, client: {}, ignore: [string], url: {refresh_token: string, token: string}}}
 */
export const OAUTH2_TOKEN = {
  url: {
    token: 'auth/oauth/token',
    refresh_token: 'auth/oauth/token'
  },
  code: {
    access_token_exp_code: "500007",
    refresh_token_exp_code: "500010",
    access_denied_code: "500009",
    img_code_error: "500012"
  },
  client: undefined,
};
